﻿using System.IO;
using System.Net.Sockets;
using System.Text;

namespace InnoLabProjektDektopApp
{
    public static class WebSocketClient
    {
        private static TcpClient _client;
        private static NetworkStream _stream;
        private static bool _isConnected = false;

        // Diese Methode stellt die Verbindung nur einmal her (wenn sie noch nicht besteht)
        public static void ConnectToServer(string serverAddress, int port)
        {
            if (_isConnected) return; // Verhindert mehrfache Verbindungen

            try
            {
                _client = new TcpClient(serverAddress, port); // Server und Port anpassen
                _stream = _client.GetStream();
                _isConnected = true;
                Console.WriteLine("Verbindung zum WebSocket-Server hergestellt.");
            }
            catch (Exception ex)
            {
                Console.WriteLine($"Fehler beim Verbinden: {ex.Message}");
            }
        }

        // Funktion, um eine Nachricht zu senden
        public static void SendMessage(string message)
        {
            if (_stream == null)
            {
                Console.WriteLine("Stream nicht verfügbar.");
                return;
            }

            try
            {
                byte[] messageBytes = Encoding.UTF8.GetBytes(message);
                _stream.Write(messageBytes, 0, messageBytes.Length);
                Console.WriteLine($"Nachricht gesendet: {message}");
            }
            catch (Exception ex)
            {
                Console.WriteLine($"Fehler beim Senden der Nachricht: {ex.Message}");
            }
        }

        // Funktion, um das Tracking zu starten
        public static void StartTracking()
        {
            // Sicherstellen, dass wir verbunden sind, bevor wir eine Nachricht senden
            ConnectToServer("localhost", 8080);
            SendMessage("{\"action\": \"startTracking\", \"status\": true}");
            SendJsonFile(@"F:\Dokumente\Schule\Studium\InoLab\procrastinator\InnoLabProjektDektopApp\InnoLabProjektDektopApp\bin\Debug\net8.0-windows\Assets\distractingWebsites.json");
        }

        // Funktion, um das Tracking zu stoppen
        public static void StopTracking()
        {
            // Sicherstellen, dass wir verbunden sind, bevor wir eine Nachricht senden
            ConnectToServer("localhost", 8080);
            SendMessage("{\"action\": \"stopTracking\", \"status\": false}");
        }

        // Funktion zum Schließen der Verbindung
        public static void CloseConnection()
        {
            _stream?.Close();
            _client?.Close();
            _isConnected = false;
            Console.WriteLine("Verbindung geschlossen.");
        }

        // Funktion, um die JSON-Datei zu laden und zu senden
        public static void SendJsonFile(string filePath)
        {
            // Überprüfen, ob die Datei existiert
            if (!File.Exists(filePath))
            {
                Console.WriteLine("Datei existiert nicht.");
                return;
            }

            // Dateiinhalt lesen
            string jsonContent = File.ReadAllText(filePath);

            // Nachricht senden (JSON-Inhalt)
            //SendMessage(jsonContent);
            string message = $"{{\"action\": \"sendJsonContent\", \"status\": true, \"content\": {jsonContent}}}";
            SendMessage(message);
        }
    }
}
