﻿using System.Net;
using System.Net.WebSockets;
using System.Text;

namespace InnoLabProjektDektopApp
{
    public static class WebSocketServer
    {
        private static HttpListener _listener = new HttpListener();
        private static WebSocket _webSocket;

        public static async void StartServer(int port)
        {
            _listener.Prefixes.Add($"http://localhost:{port}/");
            _listener.Start();
            Console.WriteLine($"WebSocket-Server läuft auf ws://localhost:{port}");

            while (true)
            {
                HttpListenerContext context = await _listener.GetContextAsync();
                if (context.Request.IsWebSocketRequest)
                {
                    HttpListenerWebSocketContext wsContext = await context.AcceptWebSocketAsync(null);
                    _webSocket = wsContext.WebSocket;
                    Console.WriteLine("WebSocket-Verbindung akzeptiert.");
                    await ReceiveMessages();
                }
                else
                {
                    context.Response.StatusCode = 400;
                    context.Response.Close();
                }
            }
        }

        private static async Task ReceiveMessages()
        {
            byte[] buffer = new byte[1024];
            while (_webSocket.State == WebSocketState.Open)
            {
                WebSocketReceiveResult result = await _webSocket.ReceiveAsync(new ArraySegment<byte>(buffer), CancellationToken.None);
                string message = Encoding.UTF8.GetString(buffer, 0, result.Count);
                Console.WriteLine($"Nachricht empfangen: {message}");

                await SendMessageToClient($"Empfangen: {message}");
            }
        }

        public static async Task SendMessageToClient(string message)
        {
            if (_webSocket != null && _webSocket.State == WebSocketState.Open)
            {
                byte[] messageBytes = Encoding.UTF8.GetBytes(message);
                await _webSocket.SendAsync(new ArraySegment<byte>(messageBytes), WebSocketMessageType.Text, true, CancellationToken.None);
                Console.WriteLine($"Nachricht gesendet: {message}");
            }
        }

        public static void StopServer()
        {
            _listener.Stop();
            _webSocket?.CloseAsync(WebSocketCloseStatus.NormalClosure, "Server gestoppt", CancellationToken.None);
            Console.WriteLine("WebSocket-Server gestoppt.");
        }
    }
}
